var mongoose = require('../mongoose.js')();

var schema = new mongoose.Schema({
  name: { type: String, require: true },
  rules: [{
    type: {type: String},
    event: { type: String, require: true },
    event_properties: [{ event_property : { type: String }, property_type: { type: String }, property_value : { type: String }, event_filter: { type: String, enum: ['equals', 'contains', 'not equals', 'greater than', 'less than', 'greater than equal to', 'less than equal to']}}],
    count: { type: Number, default: 0, require: true },
    include: { type: Boolean, default: true, require: true },
    period_seconds: { type: Number, default: 0, require: true },
    multiplier: { type: Number, default: null, require: true },//hour
    timeframe: { type: String, default: null, require: true, enum: [null, 'over', 'within'] }
  }],
  triggers: [{
    wait_seconds: { type: Number, default: 0, require: true },
    multiplier: { type: Number, default: null, require: true },//hour
    templateId: { type: mongoose.Schema.ObjectId, require: true }
  }],
  active: { type: Boolean, default: true },
  created: { type: Date, default: Date.now },
  modified: Date,
  userId: { type: mongoose.Schema.ObjectId, require: true },
  multiple: { type: Boolean, default: false },
  customers: { type: String, default: null, require: true, enum: [null, 'all', 'current', 'new'] }
});

schema.pre('save', function (next) {
  this.modified = new Date();
  next();
});

schema.virtual('id').get(function(){
  return this._id.toHexString();
});

schema.set('toJSON', {
  virtuals: true
});

module.exports = mongoose.model('Recipe', schema);
